@@ -12,8 +12,14 @@ import           Data.Foldable (concat)
 import           Control.DeepSeq (deepseq, NFData(rnf))
 import           Data.Generics
 
+#if __GLASGOW_HASKELL__ < 707
 import           GHC hiding (flags, Module, Located)
 import           MonadUtils (liftIO, MonadIO)
+#else
+import           GHC hiding (Module, Located)
+import           DynFlags
+import           MonadUtils (liftIO)
+#endif
 import           Exception (ExceptionMonad)
 import           System.Directory
 import           System.FilePath
@@ -28,6 +34,7 @@ import           GhcUtil (withGhc)
 import           Location hiding (unLoc)
 
 import           Util (convertDosLineEndings)
+import           Sandbox (getSandboxArguments)
 
 -- | A wrapper around `SomeException`, to allow for a custom `Show` instance.
 newtype ExtractError = ExtractError SomeException
@@ -79,7 +86,12 @@ parse args = withGhc args $ \modules_ -> withTempOutputDir $ do
     -- copied from Haddock/Interface.hs
     enableCompilation :: ModuleGraph -> Ghc ModuleGraph
     enableCompilation modGraph = do
+#if __GLASGOW_HASKELL__ < 707
       let enableComp d = d { hscTarget = defaultObjectTarget }
+#else
+      let enableComp d = let platform = targetPlatform d
+                         in d { hscTarget = defaultObjectTarget platform }
+#endif
       modifySessionDynFlags enableComp
       -- We need to update the DynFlags of the ModSummaries as well.
       let upd m = m { ms_hspp_opts = enableComp (ms_hspp_opts m) }
@@ -90,7 +102,15 @@ parse args = withGhc args $ \modules_ -> withTempOutputDir $ do
     modifySessionDynFlags :: (DynFlags -> DynFlags) -> Ghc ()
     modifySessionDynFlags f = do
       dflags <- getSessionDynFlags
+#if __GLASGOW_HASKELL__ < 707
       _ <- setSessionDynFlags (f dflags)
+#else
+      -- GHCi 7.7 now uses dynamic linking.
+      let dflags' = case lookup "GHC Dynamic" (compilerInfo dflags) of
+            Just "YES" -> gopt_set dflags Opt_BuildDynamicToo
+            _          -> dflags
+      _ <- setSessionDynFlags (f dflags')
+#endif
       return ()
 
     withTempOutputDir :: Ghc a -> Ghc a
@@ -122,7 +142,9 @@ parse args = withGhc args $ \modules_ -> withTempOutputDir $ do
 -- those modules (possibly indirect).
 extract :: [String] -> IO [Module (Located String)]
 extract args = do
-  mods <- parse args
+  sandboxArgs <- getSandboxArguments
+  let args'  = args ++ sandboxArgs
+  mods <- parse args'
   let docs = map (fmap (fmap convertDosLineEndings) . extractFromModule . tm_parsed_module) mods
 
   (docs `deepseq` return docs) `catches` [
