@@ -22,6 +22,7 @@ import           Data.Char
 import           Data.List
 
 import           GHC.Paths (ghc)
+import           Sandbox (getSandboxArguments)
 
 -- | Truly random marker, used to separate expressions.
 --
@@ -55,13 +56,22 @@ interpreterSupported = do
 
 newInterpreter :: [String] -> IO Interpreter
 newInterpreter flags = do
+  sandboxFlags <- getSandboxArguments
+  let myFlags = ghciFlags ++ flags ++ sandboxFlags
+  -- get examples from Haddock comments
   (Just stdin_, Just stdout_, Nothing, processHandle ) <- createProcess $ (proc ghc myFlags) {std_in = CreatePipe, std_out = CreatePipe, std_err = Inherit}
   setMode stdin_
   setMode stdout_
   let interpreter = Interpreter {hIn = stdin_, hOut = stdout_, process = processHandle}
   _ <- eval interpreter "import System.IO"
   _ <- eval interpreter "import GHC.IO.Handle"
+  -- The buffering of stdout and stderr is NoBuffering
   _ <- eval interpreter "hDuplicateTo stdout stderr"
+  -- Now the buffering of stderr is BlockBuffering Nothing
+  -- In this situation, GHC 7.7 does not flush the buffer even when
+  -- error happens.
+  _ <- eval interpreter "hSetBuffering stdout LineBuffering"
+  _ <- eval interpreter "hSetBuffering stderr LineBuffering"
 
   -- this is required on systems that don't use utf8 as default encoding (e.g.
   -- Windows)
@@ -70,8 +80,7 @@ newInterpreter flags = do
 
   return interpreter
   where
-    myFlags = ["-v0", "--interactive", "-ignore-dot-ghci"] ++ flags
-
+    ghciFlags = ["-v0", "--interactive", "-ignore-dot-ghci"]
     setMode handle = do
       hSetBinaryMode handle False
       hSetBuffering handle LineBuffering
