@@ -67,5 +67,8 @@ parseNotInScope = nub . map extractVariable . filter ("Not in scope: " `isInfixO
     extractVariable = unquote . takeWhileEnd (/= ' ')
 
     -- | Remove quotes from given name, if any.
-    unquote ('`':xs) = init xs
-    unquote xs       = xs
+    unquote ('`':xs)     = init xs
+#if __GLASGOW_HASKELL__ >= 707
+    unquote ('\8219':xs) = init xs
+#endif
+    unquote xs           = xs
